boto: A Python interface to Amazon Web Services — boto v2.31.0

### Navigation

- index
- modules |
- next |
- boto v2.31.0 »

# boto: A Python interface to Amazon Web Services

An integrated interface to current and future infrastructural services offered by Amazon Web Services.

Currently, all features work with Python 2.6 and 2.7. Work is under way to support Python 3.3+ in the same codebase. Modules are being ported one at a time with the help of the open source community, so please check below for compatibility with Python 3.3+.

To port a module to Python 3.3+, please view our Contributing Guidelines and the Porting Guide. If you would like, you can open an issue to let others know about your work in progress. Tests must pass on Python 2.6, 2.7, 3.3, and 3.4 for pull requests to be accepted.

## Getting Started

If you’ve never used `boto` before, you should read the Getting Started with Boto guide to get familiar with `boto` & its usage.

## Currently Supported Services

- Compute
  - Elastic Compute Cloud (EC2) – (API Reference)
  - Elastic MapReduce (EMR) – (API Reference) (Python 3)
  - Auto Scaling – (API Reference) (Python 3)
  - Kinesis – (API Reference) (Python 3)
- Content Delivery
  - CloudFront – (API Reference) (Python 3)
- Database
  - DynamoDB2 – (API Reference) – (Migration Guide from v1)
  - DynamoDB – (API Reference)
  - Relational Data Services 2 (RDS) – (API Reference) – (Migration Guide from v1)
  - Relational Data Services (RDS) – (API Reference)
  - ElastiCache – (API Reference) (Python 3)
  - Redshift – (API Reference) (Python 3)
  - SimpleDB – (API Reference)
- Deployment and Management
  - CloudFormation – (API Reference) (Python 3)
  - Elastic Beanstalk – (API Reference)
  - Data Pipeline – (API Reference) (Python 3)
  - Opsworks – (API Reference) (Python 3)
  - CloudTrail – (API Reference) (Python 3)
- Identity & Access
  - Identity and Access Management (IAM) – (API Reference) (Python 3)
  - Security Token Service (STS) – (API Reference)
- Application Services
  - Cloudsearch 2 – (API Reference)
  - Cloudsearch – (API Reference)
  - Elastic Transcoder – (API Reference) (Python 3)
  - Simple Workflow Service (SWF) – (API Reference) (Python 3)
  - Simple Queue Service (SQS) – (API Reference) (Python 3)
  - Simple Notification Service (SNS) – (API Reference) (Python 3)
  - Simple Email Service (SES) – (API Reference) (Python 3)
- Monitoring
  - CloudWatch – (API Reference) (Python 3)
  - CloudWatch Logs – (API Reference) (Python 3)
- Networking
  - Route 53 – (API Reference) (Python 3)
  - Virtual Private Cloud (VPC) – (API Reference)
  - Elastic Load Balancing (ELB) – (API Reference) (Python 3)
  - AWS Direct Connect (Python 3)
- Payments & Billing
  - Flexible Payments Service (FPS) – (API Reference)
- Storage
  - Simple Storage Service (S3) – (API Reference) (Python 3)
  - Amazon Glacier – (API Reference) (Python 3)
  - Google Cloud Storage – (API Reference)
- Workforce
  - Mechanical Turk – (API Reference)
- Other
  - Marketplace Web Services – (API Reference) (Python 3)
  - Support – (API Reference)

## Additional Resources

- Applications Built On Boto
- Command Line Utilities
- Boto Config Tutorial
- Contributing to Boto
- Evaluating Application performance with Boto logging
- Boto Source Repository
- Boto Issue Tracker
- Boto Twitter
- Follow Mitch on Twitter
- Join our IRC channel (#boto on FreeNode).

## Release Notes

- boto v2.30.0
- boto v2.29.1
- boto v2.29.0
- boto v2.28.0
- boto v2.27.0
- boto v2.26.1
- boto v2.26.0
- boto v2.25.0
- boto v2.24.0
- boto v2.23.0
- boto v2.22.1
- boto v2.22.0
- boto v2.21.2
- boto v2.21.1
- boto v2.21.0
- boto v2.20.1
- boto v2.20.0
- boto v2.19.0
- boto v2.18.0
- boto v2.17.0
- boto v2.16.0
- boto v2.15.0
- boto v2.14.0
- boto v2.13.3
- boto v2.13.2
- boto v2.13.0
- boto v2.12.0
- boto v2.11.0
- boto v2.10.0
- boto v2.9.9
- boto v2.9.8
- boto v2.9.7
- boto v2.9.6
- boto v2.9.5
- boto v2.9.4
- boto v2.9.3
- boto v2.9.2
- boto v2.9.1
- boto v2.9.0
- boto v2.8.0
- boto v2.7.0
- boto v2.6.0
- boto v2.5.2
- boto v2.5.1
- boto v2.5.0
- boto v2.4.0
- boto v2.3.0
- boto v2.2.2
- boto v2.2.1
- boto v2.2.0
- boto v2.1.1
- boto v2.1.0
- Release Notes for boto 2.0
- Major changes for release 2.0b1

### Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- boto v2.31.0 »